@@ -1,6 +1,6 @@
 ################################################################################
 #' Correlation sum, correlation dimension and generalized correlation dimension 
-#' (order q >1).
+#' (order q >1).   
 #' @description
 #' Functions for estimating the correlation sum and the correlation dimension of a dynamical 
 #' system from 1-dimensional time series using Takens' vectors.
@@ -53,20 +53,37 @@
 #' @param do.plot Logical value. If TRUE (default value), a plot of the correlation sum is shown.
 #' @param number.boxes Number of boxes that will be used in the box assisted algorithm (see \link{neighbourSearch}). If the user does not specify it, the function
 #' uses a proper number of boxes.
+#' @param ... Additional plotting parameters.
 #' @return  A \emph{corrDim} object that consist of a list with four components named \emph{radius}, \emph{embedding.dims}, \emph{order} and \emph{corr.matrix}.
 #' \emph{radius} is a vector containing the different radius where we have evaluated C(r). \emph{embedding.dims} is a vector containing
 #' all the embedding dimensions in which we have estimated C(r). \emph{order} stores the order of the generalized correlation dimension
 #' that has been used. Finally, \emph{corr.matrix} stores all the correlation
 #' sums that have been computed. Each row stores the correlation sum for a concrete embedding dimension whereas each colum
 #' stores the correlation sum for a specific radius. 
+#' @examples
+#' \dontrun{
+#' x=lorenz(sigma=10, rho = 28, beta =8/3, start = c(-10, -11, 47),
+#' time =  seq(0, 70, by = 0.01), do.plot = FALSE)$x
+#' cd=corrDim(time.series=x,min.embedding.dim=3,max.embedding.dim=6,
+#'            time.lag=10,min.radius=1e-3,max.radius=50,
+#'            n.points.radius=100,theiler.window=100,
+#'            number.boxes=100,do.plot=F)
+#' 
+#' plot(cd,type="l")
+#' plotLocalScalingExp(cd,cex=0.5,xlim=c(1e-1,5))
+#' cd.est = estimate(cd,regression.range=c(0.2,2))
+#' cat("expected: 2.05  --- estimate: ",cd.est,"\n")
+#' }
 #' @references H. Kantz  and T. Schreiber: Nonlinear Time series Analysis (Cambridge university press)
 #' @author Constantino A. Garcia
 #' @rdname corrDim
 #' @export corrDim
 #' @exportClass corrDim
 #' @useDynLib nonlinearTseries
-corrDim = function ( time.series, min.embedding.dim=2, max.embedding.dim = 5, time.lag=1, 
-                     min.radius,max.radius,corr.order=2,n.points.radius=5,theiler.window=100,do.plot=TRUE,number.boxes=NULL){
+corrDim = function ( time.series, min.embedding.dim=2, max.embedding.dim = 5,
+                     time.lag=1,  min.radius,max.radius,corr.order=2,
+                     n.points.radius=5,theiler.window=100,do.plot=TRUE,
+                     number.boxes=NULL,...){
  
   #estimate number of boxes for the box assisted algorithm
   if (is.null(number.boxes)) number.boxes = estimateNumberBoxes(time.series, min.radius)
@@ -76,8 +93,8 @@ corrDim = function ( time.series, min.embedding.dim=2, max.embedding.dim = 5, ti
   numberTakens=nrow(takensDimMin)
   #other C params
   lenTimeSeries=length(time.series)
-  numberEmbeddings=max.embedding.dim-min.embedding.dim+1
-  corr.matrix=matrix(0,nrow=numberEmbeddings,ncol=n.points.radius)
+  number.embeddings=max.embedding.dim-min.embedding.dim+1
+  corr.matrix=matrix(0,nrow=number.embeddings,ncol=n.points.radius)
   #radius vector. It is prepared to have equally spaced points in the log10(radius) axis
   log.radius=seq(log10(max.radius),log10(min.radius),len=n.points.radius)
   radius=10^log.radius
@@ -100,7 +117,7 @@ corrDim = function ( time.series, min.embedding.dim=2, max.embedding.dim = 5, ti
   }
 
   #get the correlation sum matrix
-  corr.matrix=matrix(sol$corrMatrix,nrow=numberEmbeddings,ncol=n.points.radius)
+  corr.matrix=matrix(sol$corrMatrix,nrow=number.embeddings,ncol=n.points.radius)
   dimnames(corr.matrix) = list(min.embedding.dim:max.embedding.dim,radius)
   #eliminate columns with at least one 0
   wh=which(corr.matrix==0,arr.ind=TRUE)
@@ -113,9 +130,15 @@ corrDim = function ( time.series, min.embedding.dim=2, max.embedding.dim = 5, ti
   # create the corrDim object
   corr.dim = list(corr.matrix = corr.matrix,embedding.dims = min.embedding.dim:max.embedding.dim,radius=radius,corr.order=corr.order)
   class(corr.dim) = "corrDim"
+  # add attributes
+  id=deparse(substitute(time.series))
+  attr(corr.dim,"time.lag") = time.lag
+  attr(corr.dim,"id") = id
+  attr(corr.dim,"theiler.window") = theiler.window
+  
   # plot if necessary
   if (do.plot){
-    plot(corr.dim)
+    plot(corr.dim,...)
   }
   
   return(corr.dim)
@@ -125,7 +148,7 @@ corrDim = function ( time.series, min.embedding.dim=2, max.embedding.dim = 5, ti
 #' @return The \emph{nlOrder} function returns the order of the correlation sum.
 #' @rdname corrDim
 #' @method nlOrder corrDim
-#' @S3method nlOrder corrDim
+#' @export
 nlOrder.corrDim = function(x){
   return (x$corr.order)
 }
@@ -147,7 +170,7 @@ corrMatrix = function(x){
 #' dimensions.
 #' @rdname corrDim
 #' @method corrMatrix corrDim
-#' @S3method corrMatrix corrDim
+#' @export
 corrMatrix.corrDim = function(x){
   return (x$corr.matrix)
 }
@@ -155,7 +178,7 @@ corrMatrix.corrDim = function(x){
 #' @return The \emph{radius} function returns the radius on which the correlation sum function has been evaluated.
 #' @rdname corrDim
 #' @method radius corrDim
-#' @S3method radius corrDim
+#' @export
 radius.corrDim = function(x){
   return (radius.default(x))
 }
@@ -164,79 +187,150 @@ radius.corrDim = function(x){
 #' the correlation sum function has been evaluated.
 #' @rdname corrDim
 #' @method embeddingDims corrDim
-#' @S3method embeddingDims corrDim
+#' @export
 embeddingDims.corrDim = function(x){
   return (embeddingDims.default(x))
 }
 
 
 #' @rdname corrDim
-#' @param ... Additional parameters.
 #' @method print corrDim
-#' @S3method print corrDim
+#' @export
 print.corrDim = function(x, ...){
   print(x$corr.matrix)
 }
 
-
-#' @return The \emph{plot} function shows two graphics of the correlation integral:
-#' a log-log plot of the correlation sum Vs the radius and the local slopes of 
-#' \eqn{log10(C(r))\;Vs\;log10(C(r)).}{log10(C(r)) Vs log10(C(r)).}
+#' @param main A title for the plot.
+#' @param xlab A title for the x axis.
+#' @param ylab A title for the y axis.
+#' @param type Type of plot (see \code{\link[graphics]{plot}}).
+#' @param log A character string which contains "x" if the x axis is to be 
+#' logarithmic, "y" if the y axis is to be logarithmic and "xy" or "yx" if both 
+#' axes are to be logarithmic.
+#' @param ylim Numeric vector of length 2, giving the y coordinates range.
+#' @param col Vector of colors for each of the dimensions of the plot.
+#' @param pch Vector of symbols for each of the dimensions of the plot.
+#' @param localScalingExp add a plot of the local scaling exponents of the correlation
+#' sum.
+#' @param add.legend add a legend to the plot?
+#' @param cex.legend Magnification value for the legend.
+#' @return The \emph{plot} function plots the correlation sum. It is possible to
+#' plot the the correlation sum Vs the radius and also the local scaling exponents
+#'  of the correlation  sum Vs radius.
 #' @rdname corrDim
 #' @method plot corrDim
-#' @S3method plot corrDim
+#' @export
 #' @method plot
-plot.corrDim = function(x, ...){
-   current.par = par() 
-   # Check if it is possible to compute local slopes and
-   # set layout depending on it
-   if ( ncol(x$corr.matrix) > 1) {
-      # it is possible... 3 regions
-      layout(rbind(1,2,3), heights=c(4,4,2))
-    }else{
-      # not possible... just 2 regions (not local slopes)
+plot.corrDim = function(x,main="Correlation Sum C(r)",xlab=NULL,
+                        ylab="C(r)",type="b",
+                        log="xy",ylim=NULL, col=NULL,pch=NULL,localScalingExp=T,
+                        add.legend=T,cex.legend=1,...){
+   # set layout depending on options
+  if ( add.legend || localScalingExp ){
+    current.par =  par(no.readonly = TRUE)
+    on.exit(par(current.par))
+  }
+  if (add.legend && localScalingExp){
+    # 3 regions
+    layout(rbind(1,2,3), heights=c(4,4,2))
+  }else{
+    if (add.legend){
+      # add legend
       layout(rbind(1,2), heights=c(8,2))
     }
-    number.embeddings=nrow(x$corr.matrix)
-    ### log-log plot
-    xlab = ifelse(x$corr.order==2,{"Radius r"},{paste("Radius r^",x$corr.order-1,"",sep="")})
-    plot(x$radius^(x$corr.order-1),x$corr.matrix[1,],log="xy",'b',col=1,cex=0.3,ylim=range(x$corr.matrix),
-         xlab=xlab,ylab="Correlation Sum C(r)",main="Correlation Sum Vs radius")
-    i=2
-    while(i<=number.embeddings){
-      lines(x$radius^(x$corr.order-1),x$corr.matrix[i,],'b',col=i,cex=0.3)
-      i = i + 1
+    if (localScalingExp){
+      # add local slopes
+      layout(rbind(1,2), heights=c(5,5))
     }
-    #### local slopes
-    # Check if it is possible to compute local slopes
-    if ( ncol(x$corr.matrix) > 1) {
-      lcm = log10(x$corr.matrix)
-      dlcm= matrix(
-                    t(apply(lcm,MARGIN=1,differentiate, 
-                          h = (x$corr.order-1)*(log10(x$radius[[2]])-log10(x$radius[[1]]))
-                          )),
-                    nrow = number.embeddings)
-      dlcm=10^dlcm
-      radius.axis = differentiateAxis(x$radius)
-      xlab = ifelse(x$corr.order==2,{"Radius r"},{paste("Radius r^",x$corr.order-1,"",sep="")})
-      plot(radius.axis^(x$corr.order-1),dlcm[1,],'b',log="xy",cex=0.3,col=1,ylim=range(dlcm),
-           xlab=xlab,ylab="Local slopes of the Correlation Sum",main="Local slopes of the Correlation Sum Vs Radius")
-      i=2
-      while(i <= number.embeddings){
-        lines(radius.axis^(x$corr.order-1),dlcm[i,],'b',cex=0.3,col=i)
-        i=i+1
-      }
-    }
-    ### add legend
+  }
+  number.embeddings=nrow(x$corr.matrix)
+  # plot options
+  if (is.null(ylim)) ylim=range(x$corr.matrix)
+  if (is.null(xlab)) {
+    xlab = ifelse(x$corr.order==2,{"Radius r"}, {paste("Radius r^",x$corr.order-1,"",sep="")})
+  }
+  col = vectorizePar(col,number.embeddings)
+  pch = vectorizePar(pch,number.embeddings)
+  # plot
+  plot(x$radius^(x$corr.order-1),x$corr.matrix[1,],type=type,log=log,
+       col=col[[1]], pch=pch[[1]],ylim=ylim, xlab=xlab,ylab=ylab,main=main,...)
+  i=2
+  while(i<=number.embeddings){
+    lines(x$radius^(x$corr.order-1),x$corr.matrix[i,],type=type,col=col[[i]],
+          pch=pch[[i]],...)
+    i = i + 1
+  }
+  #### add local slopes if needed
+  if (localScalingExp){
+    plotLocalScalingExp(x,xlab = xlab,type = type,col = col,pch=pch,
+                    add.legend = F,...)
+  }
+  ### add legend
+  if (add.legend){
     par(mar=c(0, 0, 0, 0))
     plot.new()
     legend("center","groups",ncol=ceiling(number.embeddings/2), 
-           col=1:number.embeddings,lty=rep(1,number.embeddings),
+           bty="n", col=col,lty=rep(1,number.embeddings),pch=pch,
+           lwd=rep(2.5,number.embeddings), cex=cex.legend,
+           legend=x$embedding.dims, title="Embedding dimension")
+  }   
+}
+
+
+#' @return The \emph{plotLocalScalingExp} function plots the local scaling exponents
+#'  of  the  correlation sum.
+#' @rdname corrDim
+#' @method plotLocalScalingExp corrDim
+#' @export
+#' @method plotLocalScalingExp
+plotLocalScalingExp.corrDim = function(x,main="Correlation Dimension C(r)",
+                                   xlab=NULL,ylab="Local scaling exponents",
+                                   type="b",log="x",ylim=NULL,col=NULL,pch=NULL,
+                                   add.legend=T, ...){
+  # Check if it is possible to compute local slopes
+  if ( ncol(x$corr.matrix) <= 1) {
+    stop("Cannot compute local scaling exponents (not enough points in the correlation matrix)")
+  }
+  
+  number.embeddings=nrow(x$corr.matrix)
+  
+  if (add.legend){
+    current.par =  par(no.readonly = TRUE)
+    on.exit(par(current.par))
+    layout(rbind(1,2), heights=c(8,2))
+  }  
+  lcm = log10(x$corr.matrix)
+  dlcm= matrix(
+    t(apply(lcm,MARGIN=1,differentiate, 
+            h = (x$corr.order-1)*(log10(x$radius[[2]])-log10(x$radius[[1]]))
+    )),
+    nrow = number.embeddings)
+  #dlcm=10^dlcm
+  radius.axis = differentiateAxis(x$radius)
+  # obtain default parameters if not specified
+  if (is.null(ylim)) ylim=range(dlcm)
+  if (is.null(xlab)) {
+    xlab = ifelse(x$corr.order==2,{"Radius r"}, {paste("Radius r^",x$corr.order-1,"",sep="")})
+  }
+  col = vectorizePar(col,number.embeddings)
+  pch = vectorizePar(pch,number.embeddings)
+  # plot
+  plot(radius.axis^(x$corr.order-1),dlcm[1,],type=type,log=log,col=col[[1]],
+       pch=pch[[1]],ylim=ylim,xlab=xlab,ylab=ylab,main=main,...)
+  i=2
+  while(i <= number.embeddings){
+    lines(radius.axis^(x$corr.order-1),dlcm[i,],type=type,col=col[[i]],
+          pch=pch[[i]],...)
+    i=i+1
+  }
+  if (add.legend){
+    par(mar=c(0, 0, 0, 0))
+    plot.new()
+    legend("center","groups",ncol=ceiling(number.embeddings/2), 
+           bty="n", col=col,lty=rep(1,number.embeddings),pch=pch,
            lwd=rep(2.5,number.embeddings),
            legend=x$embedding.dims, title="Embedding dimension")
-    par(mar=current.par$mar)
-    par(mfrow=c(1,1))
-    
+  }
 }
 
 #' @return The \emph{estimate} function estimates the correlation dimension of the 
@@ -246,23 +340,32 @@ plot.corrDim = function(x, ...){
 #' a graphic of the regression over the data is shown.
 #' @param use.embeddings A numeric vector specifying which embedding dimensions should the \emph{estimate} function use to compute
 #' the correlation dimension.
+#' @param fit.col A vector of colors to plot the regression lines.
+#' @param fit.lty The type of line to plot the regression lines.
+#' @param fit.lwd The width of the line for the regression lines.
+#' @param lty The line type of the correlation sums.
+#' @param lwd The line width of the correlation sums.
 #' @param x A \emph{corrDim} object.
 #' @param regression.range Vector with 2 components denoting the range where the function will perform linear regression.
 #' @rdname corrDim
-#' @S3method estimate corrDim
+#' @export
 #' @method estimate corrDim
 #' 
 estimate.corrDim=function(x, regression.range = NULL, do.plot=FALSE,
-                          use.embeddings = NULL,...){
+                          use.embeddings = NULL,col=NULL,pch=NULL,
+                          fit.col=NULL, fit.lty=2,fit.lwd=2,
+                          add.legend=T, lty=1,lwd=1,...){
   corr.matrix = corrMatrix(x)
   if (!is.null(use.embeddings)){
     corr.matrix = corr.matrix[as.character(use.embeddings),]
+  }else{
+    use.embeddings= as.numeric(rownames(corr.matrix))
   }
   average=0
   #x axis
   q = nlOrder(x)
   radius=radius(x)
-  numberEmbeddings=nrow(corr.matrix)
+  number.embeddings=nrow(corr.matrix)
   log.radius = log10(radius)
   if (is.null(regression.range)){
     r.min = min(radius)
@@ -274,30 +377,46 @@ estimate.corrDim=function(x, regression.range = NULL, do.plot=FALSE,
   }
   lcm = log10(corr.matrix)
   if (do.plot){
-    plot(radius^(q-1),lcm[1,],'b',log="x",col=1,
-         cex=0.3,ylim=c(lcm[numberEmbeddings,
-         ncol(corr.matrix)],lcm[1,1]),...)
-    i=2
-    while(i<=numberEmbeddings){
-      lines(radius^(q-1),lcm[i,],'b',col=i,cex=0.3)
-      i=i+1
-    } 
+    if (add.legend){
+      current.par =  par(no.readonly = TRUE)
+      on.exit(par(current.par))
+      layout(rbind(1,2), heights=c(8,2))
+    }
+    # obtain vector of graphical parameters if not specified
+    col = vectorizePar(col,number.embeddings)
+    pch = vectorizePar(pch,number.embeddings)
+    fit.col = vectorizePar(fit.col,number.embeddings,col)
+    # eliminate thos dimensions that are innecesary for plotting
+    reduced.x=x
+    reduced.x$corr.matrix = NULL
+    reduced.x$corr.matrix = corr.matrix
+    reduced.x$embedding.dims = NULL
+    reduced.x$embedding.dims = use.embeddings
+    plot(reduced.x,col=col,pch=pch,lty=lty,lwd=lwd,add.legend=F,localScalingExp=F,...)
   }
   #average over differents embedding dimensions
-  for (i in 1:numberEmbeddings){
+  for (i in 1:number.embeddings){
     new.corr = eliminateDuplicates(corr.matrix[i,] , radius)
     indx = which(new.corr$radius >= r.min & new.corr$radius <= r.max)
     y.values = log10(new.corr$correlation[indx])
     x.values = (q-1)*log10(new.corr$radius[indx])
     fit=lm(y.values ~ x.values)
     if (do.plot){
-      lines(new.corr$radius[indx]^(q-1),fit$fitted.values,
-            col="blue",type="b",cex=0.3)
+      lines(new.corr$radius[indx]^(q-1),10^fit$fitted.values,
+            col=fit.col[[i]],lwd=fit.lwd,lty=fit.lty,...)
     }
     #print(fit$coefficients[[2]])
     average=average + fit$coefficients[[2]]
   }
-  average=average/numberEmbeddings
+  if (add.legend && do.plot ){
+    par(mar=c(0, 0, 0, 0))
+    plot.new()
+    legend("center","groups",ncol=ceiling(number.embeddings/2), 
+           bty="n", col=col,lty=rep(1,number.embeddings),pch=pch,
+           lwd=rep(2.5,number.embeddings),
+           legend=use.embeddings, title="Embedding dimension")
+  }   
+  average=average/number.embeddings
   #return the correlation dimension estimate
   return(average)
 }
