@@ -23,6 +23,7 @@
 #' @param number.time.steps Integer denoting the number of temporal jumps in steps of \emph{time.step} in which we want to compute the space time plot.
 #' @param numberPercentages Number of contour lines to be computed. Each contour line represent a concrete percentage of points (see Details).
 #' @param do.plot Logical. If TRUE, the time space plot is shown.
+#' @param ... Additional plotting parameters.
 #' @return A \emph{timeSpacePlot} object that consist, essentially, of a matrix storing the values for each contour line.
 #' Each row stores the value for a given percentage of points. Each column stores the value of the radius you have to go to
 #'  find a given fraction of neighbour pairs (the rows), depending on their temporal separation (the colums). This matrix 
@@ -38,7 +39,11 @@
 #' @export spaceTimePlot
 #' @exportClass spaceTimePlot
 #' @useDynLib nonlinearTseries
-spaceTimePlot=function(takens = NULL, time.series=NULL, embedding.dim=2, time.lag=1,max.radius=NULL, time.step=1 , number.time.steps = NULL, numberPercentages=10,do.plot=TRUE){
+spaceTimePlot=function(takens = NULL, 
+                       time.series=NULL, embedding.dim=2, 
+                       time.lag=1,max.radius=NULL, time.step=1,
+                       number.time.steps = NULL, numberPercentages=10,
+                       do.plot=TRUE,...){
   ### define
   kLengthRadiusVector = 1000
   kTimeStepsDefault = 500
@@ -74,16 +79,15 @@ spaceTimePlot=function(takens = NULL, time.series=NULL, embedding.dim=2, time.la
   dimnames(stp.matrix)  = list(percentagePoints=100*(1:numberPercentages)/numberPercentages,number.time.steps=1:number.time.steps)
   stp = list(stp.matrix=stp.matrix,time.step=time.step,time.axis = 1:number.time.steps)
   class(stp) = "spaceTimePlot"
+  stp = propagateTakensAttr(stp,takens)
   
   #plot if necessary
   if (do.plot){
-    plot(stp)
+    plot(stp,...)
   }
   
   return (stp)
   
-  
-  
 }
 
 
@@ -103,7 +107,7 @@ contourLines = function(x){
 #' @param x A \emph{spaceTimePlot} object.
 #' @rdname spaceTimePlot
 #' @method contourLines spaceTimePlot
-#' @S3method contourLines spaceTimePlot
+#' @export
 contourLines.spaceTimePlot = function(x){
   return (x$stp.matrix)
 }
@@ -111,31 +115,56 @@ contourLines.spaceTimePlot = function(x){
 
 #' @rdname spaceTimePlot
 #' @method plot spaceTimePlot
-#' @param ... Additional parameters.
-#' @S3method plot spaceTimePlot
-plot.spaceTimePlot = function(x, ...){
+#' @param main A title for the plot.
+#' @param xlab A title for the x axis.
+#' @param ylab A title for the y axis.
+#' @param type Type of plot (see \code{\link[graphics]{plot}}).
+#' @param ylim Numeric vector of length 2, giving the y coordinates range.
+#' @param col Vector of colors for each of the percentages of the plot.
+#' @param pch Vector of symbols for each of the percentages of the plot.
+#' @param add.legend add a legend to the plot?
+#' @export
+plot.spaceTimePlot = function(x, main = "Space time separation plot",xlab=NULL,
+                              ylab=NULL,type = "l", ylim=NULL,
+                              col = NULL, pch = NULL,
+                              add.legend=TRUE,
+                              ...){
   # auxiliar parameters for plotting
   timeSteps=x$time.axis
   numberPercentages = nrow(x$stp.matrix)
-  xlab = paste("Number of time steps, in steps of ", x$time.step)
-  ylab = expression("Distance to reference point ("*epsilon*")")
+  if (is.null(xlab)) xlab = paste("Number of time steps, in steps of ",
+                                  x$time.step)
+  if (is.null(ylab)) ylab = expression("Distance to reference point ("*epsilon*")")
+  if (is.null(ylim)) ylim = ylim=c(0,1.1*max(x$stp.matrix))
+  # obtain vector of graphical parameters if not specified
+  col = vectorizePar(col,numberPercentages)
+  pch = vectorizePar(pch,numberPercentages)
   
-  current.par = par()
-  layout(rbind(1,2), heights=c(8,2))
+  if (add.legend){
+    current.par =  par(no.readonly = TRUE)
+    on.exit(par(current.par))
+    layout(rbind(1,2), heights=c(8,2))
+  }
   # plot first using plot
-  plot(timeSteps,x$stp.matrix[1,],'l',xlab=xlab, ylab = ylab, main ="Space time separation plot",ylim=c(0,1.1*max(x$stp.matrix)))
+  plot(timeSteps,x$stp.matrix[1,],type=type,col=col[[1]],pch=pch[[1]]
+       ,xlab=xlab, ylab = ylab, main =main, ylim=ylim,...)
   legend.text = paste(100*1/numberPercentages,"%")
   # plot using lines
   if (numberPercentages>1){
     for (i in 2:numberPercentages){
-      lines(timeSteps,x$stp.matrix[i,],col=i)
+      lines(timeSteps,x$stp.matrix[i,],type=type, col=col[[i]],pch=pch[[i]],...)
       legend.text = c(legend.text,paste(100*i/numberPercentages,"%"))
     }
   }
-  par(mar=c(0, 0, 0, 0))
-  # c(bottom, left, top, right)
-  plot.new()
-  legend("center","groups",ncol=numberPercentages/2,col=1:numberPercentages,lty=rep(1,numberPercentages),lwd=rep(2.5,numberPercentages),
-         legend=legend.text,title="Percentage of neighbour pairs")
-  par(mar=current.par$mar)
+  if(add.legend){
+    par(mar=c(0, 0, 0, 0))
+    # c(bottom, left, top, right)
+    plot.new()
+    legend("center","groups",ncol=numberPercentages/2,
+           col=col,lty=rep(1,numberPercentages),
+           lwd=rep(2.5,numberPercentages),bty="n",
+           legend=legend.text,title="Percentage of neighbour pairs")
+
+  }
+  
 }
